package Module::Build::Platform::VOS;

use strict;
use warnings;
our $VERSION = '0.4210';
$VERSION = eval $VERSION;
use Module::Build::Base;

our @ISA = qw(Module::Build::Base);


1;
__END__


=head1 NAME

Module::Build::Platform::VOS - Builder class for VOS platforms

=head1 DESCRIPTION

The sole purpose of this module is to inherit from
C<Module::Build::Base>.  Please see the L<Module::Build> for the docs.

=head1 AUTHOR

Ken Williams <kwilliams@cpan.org>

=head1 SEE ALSO

perl(1), Module::Build(3), ExtUtils::MakeMaker(3)

=cut
